package ru.myitschool.work.data

import io.ktor.client.request.headers
import io.ktor.client.request.patch
import io.ktor.client.request.setBody
import io.ktor.http.ContentType
import io.ktor.http.HttpHeaders
import io.ktor.http.HttpStatusCode
import io.ktor.http.contentType
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext
import ru.myitschool.work.core.Constants
import ru.myitschool.work.data.dto.QrDto
import ru.myitschool.work.data.network.KtorClient
import ru.myitschool.work.domain.entities.QrEntity

object QrNetworkDataSource {

    suspend fun pushQr(qrEntity: QrEntity, token: String): Result<Unit>  = withContext(Dispatchers.IO) {

        runCatching {

            val response = KtorClient.client.patch("${Constants.SERVER_ADDRESS}/api/push_qr") {
                headers {
                    append(HttpHeaders.Authorization, token)
                }
                contentType(ContentType.Application.Json)
                setBody(
                    QrDto(code = qrEntity.code)
                )

            }
            if (response.status != HttpStatusCode.OK)
                error("Status ${response.status}")
            Unit
        }
    }
}