package ru.myitschool.work.data.network

import io.ktor.client.call.body
import io.ktor.client.request.get
import io.ktor.client.request.headers
import io.ktor.http.HttpHeaders
import io.ktor.http.HttpStatusCode
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext
import ru.myitschool.work.core.Constants
import ru.myitschool.work.data.dto.UserDto

object UserNetworkDataSource {

    suspend fun isUserExist(login: String): Result<Boolean> = withContext(Dispatchers.IO) {
        runCatching {
            val result = KtorClient.client.get("${Constants.SERVER_ADDRESS}/api/employees/$login")
            result.status == HttpStatusCode.OK
        }
    }

    suspend fun login(token: String): Result<UserDto> =
        withContext(Dispatchers.IO) {
            runCatching {
                val result =
                    KtorClient.client.get("${Constants.SERVER_ADDRESS}/api/employees/login") {
                        headers {
                            append(HttpHeaders.Authorization, token)
                        }
                    }
                if (result.status != HttpStatusCode.OK)
                    error("Status ${result.status}")
                result.body()
            }
        }

    suspend fun isRoleHasAdminPermissions(roleId: Int, token: String): Result<Boolean> =
        withContext(Dispatchers.IO) {
            runCatching {
                val response =
                    KtorClient.client.get("${Constants.SERVER_ADDRESS}/api/roles/info?$roleId") {
                        headers {
                            append(HttpHeaders.Authorization, token)
                        }
                    }

                response.status == HttpStatusCode.OK
            }
        }

    suspend fun getUserByLogin(login: String, token: String): Result<UserDto> =
        withContext(Dispatchers.IO) {
            runCatching {
                val response =
                    KtorClient.client.get("${Constants.SERVER_ADDRESS}/api/employees/find?${login}") {
                        headers {
                            append(HttpHeaders.Authorization, token)
                        }
                    }

                if (response.status == HttpStatusCode.OK)
                    error("Status ${response.status}")
                response.body()
            }
        }
}