package ru.myitschool.work.ui.profile

import android.os.Bundle
import android.view.View
import androidx.appcompat.app.AlertDialog
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.findNavController
import androidx.paging.LoadState
import com.squareup.picasso.Picasso
import ru.myitschool.work.R
import ru.myitschool.work.databinding.FragmentUserBinding
import ru.myitschool.work.utils.collectWithLifecycle
import ru.myitschool.work.utils.visibleOrGone

class UserFragment : Fragment(R.layout.fragment_user) {

    private var _binding: FragmentUserBinding? = null
    private val binding: FragmentUserBinding get() = _binding!!

    private val viewModel by viewModels<UserViewModel> { UserViewModel.Factory }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        _binding = FragmentUserBinding.bind(view)

        val adapter = PassesListAdapter()
        binding.passes.adapter = adapter

        viewModel.state.collectWithLifecycle(this) { state ->
            binding.refresh.isRefreshing = state is UserViewModel.State.Loading
            binding.content?.visibleOrGone(state is UserViewModel.State.Show)
            when (state) {
                is UserViewModel.State.Loading -> Unit
                is UserViewModel.State.Show -> {
                    val user = state.userEntity
                    binding.findUser.visibleOrGone(user.isAdmin)
                    binding.fullname.text = user.name
                    binding.position.text = user.position
                    binding.lastEntry.text = user.lastVisit
                    Picasso.get().load(user.photoUrl).into(binding.photo)
                }
            }

            viewModel.listState.collectWithLifecycle(this) { listState ->
                adapter.submitData(listState)
            }

            adapter.loadStateFlow.collectWithLifecycle(this) { data ->
                val dataState = data.refresh
                binding.refresh.isRefreshing = dataState is LoadState.Loading
                binding.error.visibleOrGone(dataState is LoadState.Error)

                if (dataState is LoadState.Error) {
                    binding.error.text = dataState.error.toString()
                }
            }

            binding.refresh.setOnRefreshListener {
                viewModel.onRefresh()
                adapter.refresh()
            }

            binding.logout.setOnClickListener {
                AlertDialog.Builder(requireContext())
                    .setTitle("Выход")
                    .setMessage("Вы уверены, что хотите выйти из аккаунта?")
                    .setIcon(android.R.drawable.ic_dialog_alert)
                    .setPositiveButton(android.R.string.ok) { _, _ -> viewModel.onLogout() }
                    .show()
                findNavController().navigate(R.id.action_userFragment_to_loginFragment)
            }

            binding.findUser.setOnClickListener {
                findNavController().navigate(R.id.find_user)
            }
        }
    }

    override fun onDestroy() {
        _binding = null
        super.onDestroy()
    }
}